import { __esDecorate, __runInitializers, __setFunctionName } from "tslib";
import { MdcComponent, number, booleanAttr } from '@aurelia-mdc-web/base';
import { MDCLinearProgressFoundation } from '@material/linear-progress';
import { inject, customElement, bindable } from 'aurelia';
import template from './mdc-linear-progress.html';
/**
 * @selector mdc-linear-progress
 */
let MdcLinearProgress = (() => {
    let _classDecorators = [inject(Element), customElement({ name: 'mdc-linear-progress', template })];
    let _classDescriptor;
    let _classExtraInitializers = [];
    let _classThis;
    let _classSuper = MdcComponent;
    let _progress_decorators;
    let _progress_initializers = [];
    let _progress_extraInitializers = [];
    let _buffer_decorators;
    let _buffer_initializers = [];
    let _buffer_extraInitializers = [];
    let _open_decorators;
    let _open_initializers = [];
    let _open_extraInitializers = [];
    var MdcLinearProgress = _classThis = class extends _classSuper {
        progressChanged() {
            const determinate = this.progress !== undefined && !isNaN(this.progress);
            this.foundation?.setDeterminate(determinate);
            if (determinate) {
                this.foundation?.setProgress(this.progress);
            }
        }
        bufferChanged() {
            if (this.buffer !== undefined && !isNaN(this.buffer)) {
                this.foundation?.setBuffer(this.buffer);
            }
        }
        openChanged() {
            if (this.open) {
                this.foundation?.open();
            }
            else {
                this.foundation?.close();
            }
        }
        initialSyncWithDOM() {
            this.progressChanged();
            if (this.open !== undefined) {
                this.openChanged();
            }
            this.bufferChanged();
        }
        getDefaultFoundation() {
            // DO NOT INLINE this variable. For backward compatibility, foundations take a Partial<MDCFooAdapter>.
            // To ensure we don't accidentally omit any methods, we need a separate, strongly typed adapter variable.
            const adapter = {
                addClass: (className) => {
                    this.root.classList.add(className);
                },
                forceLayout: () => {
                    this.root.getBoundingClientRect();
                },
                setBufferBarStyle: (styleProperty, value) => {
                    const bufferBar = this.root.querySelector(MDCLinearProgressFoundation.strings.BUFFER_BAR_SELECTOR);
                    if (bufferBar) {
                        bufferBar.style.setProperty(styleProperty, value);
                    }
                },
                setPrimaryBarStyle: (styleProperty, value) => {
                    const primaryBar = this.root.querySelector(MDCLinearProgressFoundation.strings.PRIMARY_BAR_SELECTOR);
                    if (primaryBar) {
                        primaryBar.style.setProperty(styleProperty, value);
                    }
                },
                hasClass: (className) => this.root.classList.contains(className),
                removeAttribute: (attributeName) => {
                    this.root.removeAttribute(attributeName);
                },
                removeClass: (className) => {
                    this.root.classList.remove(className);
                },
                setAttribute: (attributeName, value) => {
                    this.root.setAttribute(attributeName, value);
                },
                setStyle: (name, value) => {
                    this.root.style.setProperty(name, value);
                },
                attachResizeObserver: (callback) => {
                    const RO = window.ResizeObserver;
                    if (RO) {
                        const ro = new RO(callback);
                        ro.observe(this.root);
                        return ro;
                    }
                    return null;
                },
                getWidth: () => this.root.offsetWidth
            };
            return new MDCLinearProgressFoundation(adapter);
        }
        constructor() {
            super(...arguments);
            /** Sets the progress bar to this value. Value should be between [0, 1] or undefined for indeterminate progress indicator. */
            this.progress = __runInitializers(this, _progress_initializers, void 0);
            /** Sets the buffer bar to this value. Value should be between [0, 1] or undefined. */
            this.buffer = (__runInitializers(this, _progress_extraInitializers), __runInitializers(this, _buffer_initializers, void 0));
            /** Sets the component open state */
            this.open = (__runInitializers(this, _buffer_extraInitializers), __runInitializers(this, _open_initializers, void 0));
            __runInitializers(this, _open_extraInitializers);
        }
    };
    __setFunctionName(_classThis, "MdcLinearProgress");
    (() => {
        const _metadata = typeof Symbol === "function" && Symbol.metadata ? Object.create(_classSuper[Symbol.metadata] ?? null) : void 0;
        _progress_decorators = [bindable({ set: number })];
        _buffer_decorators = [bindable({ set: number })];
        _open_decorators = [bindable({ set: booleanAttr })];
        __esDecorate(null, null, _progress_decorators, { kind: "field", name: "progress", static: false, private: false, access: { has: obj => "progress" in obj, get: obj => obj.progress, set: (obj, value) => { obj.progress = value; } }, metadata: _metadata }, _progress_initializers, _progress_extraInitializers);
        __esDecorate(null, null, _buffer_decorators, { kind: "field", name: "buffer", static: false, private: false, access: { has: obj => "buffer" in obj, get: obj => obj.buffer, set: (obj, value) => { obj.buffer = value; } }, metadata: _metadata }, _buffer_initializers, _buffer_extraInitializers);
        __esDecorate(null, null, _open_decorators, { kind: "field", name: "open", static: false, private: false, access: { has: obj => "open" in obj, get: obj => obj.open, set: (obj, value) => { obj.open = value; } }, metadata: _metadata }, _open_initializers, _open_extraInitializers);
        __esDecorate(null, _classDescriptor = { value: _classThis }, _classDecorators, { kind: "class", name: _classThis.name, metadata: _metadata }, null, _classExtraInitializers);
        MdcLinearProgress = _classThis = _classDescriptor.value;
        if (_metadata) Object.defineProperty(_classThis, Symbol.metadata, { enumerable: true, configurable: true, writable: true, value: _metadata });
        __runInitializers(_classThis, _classExtraInitializers);
    })();
    return MdcLinearProgress = _classThis;
})();
export { MdcLinearProgress };
//# sourceMappingURL=mdc-linear-progress.js.map